import { apiInstance } from "@/shared/config/apiConfig";
import { IFetch } from "@/shared/types/fetch-type";
import { IList } from "@/shared/types/list-type";
import { IStatistics } from "@/shared/types/statistics-type";
import { AxiosError } from "axios";
import { create } from "zustand";

const filterCategories: Record<string, string> = {
  broken_road_1: "broken_road_1",
  hotbed_of_accidents_2: "hotbed_of_accidents_2",
  local_defect_3: "local_defect_3",
  repair_plans_4: "repair_plans_4",
  repaired_5: "repaired_5",
  local_defect_fixed_6: "local_defect_fixed_6",
};

interface IStatisticsStore extends IFetch {
  data: IStatistics[];
  getStatistics: (
    endpoint: string,
    sort: string,
    query: string
  ) => void;
}

export const useStatisticsStore = create<IStatisticsStore>((set) => ({
  isLoading: false,
  error: "",
  data: [],
  getStatistics: async (
    endpoint: string,
    sort: string,
    query: string = ""
  ) => {
    try {
      set({ isLoading: true });
      const response = await apiInstance.get<IStatistics[]>(
        `/report/${endpoint}/stats`
      );

      let data = response.data.filter((loc) =>
        loc.name.toLowerCase().includes(query.toLowerCase())
      );

      const sorted = data.sort((a: any, b: any) => a[sort] - b[sort]);

      set({ data: sorted });
    } catch (error: unknown) {
      if (error instanceof AxiosError) {
        set({ error: error.message });
      } else {
        set({ error: "an error ocured" });
      }
    } finally {
      set({ isLoading: false });
    }
  },
}));
